@@ -55,6 +55,8 @@ def tbyt_decoding_kfold(data, labels, n=2, navg=5, time_win=5, time_step=5, nfol
 
     if np.shape(data)[0] != np.shape(labels)[0]:
 
+        print("\nThe number of epochs doesn't match the number of labels.\n")
+
         return "Invalid input!"
 
     nsubs, ntrials, nchls, nts = np.shape(data)
@@ -70,10 +72,14 @@ def tbyt_decoding_kfold(data, labels, n=2, navg=5, time_win=5, time_step=5, nfol
 
     if len(set(ncategories.tolist())) != 1:
 
+        print("\nInvalid labels!\n")
+
         return "Invalid input!"
 
     if n != ncategories[0]:
 
+        print("\nThe number of categories for decoding doesn't match ncategories (" + str(ncategories) + ")!\n")
+
         return "Invalid input!"
 
     categories = list(sublabels_set)
@@ -154,7 +160,7 @@ def tbyt_decoding_kfold(data, labels, n=2, navg=5, time_win=5, time_step=5, nfol
 
         acc[sub] = np.average(subacc, axis=(0, 2))
 
-    if smooth == True:
+    if smooth is True:
 
         smooth_acc = np.zeros([nsubs, newnts])
 
@@ -217,6 +223,8 @@ def tbyt_decoding_holdout(data, labels, n=2, navg=5, time_win=5, time_step=5, it
 
     if np.shape(data)[0] != np.shape(labels)[0]:
 
+        print("\nThe number of epochs doesn't match the number of labels.\n")
+
         return "Invalid input!"
 
     nsubs, ntrials, nchls, nts = np.shape(data)
@@ -232,10 +240,14 @@ def tbyt_decoding_holdout(data, labels, n=2, navg=5, time_win=5, time_step=5, it
 
     if len(set(ncategories.tolist())) != 1:
 
+        print("\nInvalid labels!\n")
+
         return "Invalid input!"
 
     if n != ncategories[0]:
 
+        print("\nThe number of categories for decoding doesn't match ncategories (" + str(ncategories) + ")!\n")
+
         return "Invalid input!"
 
     categories = list(sublabels_set)
@@ -252,6 +264,8 @@ def tbyt_decoding_holdout(data, labels, n=2, navg=5, time_win=5, time_step=5, it
 
     total = nsubs * iter * newnts
 
+    print("\nDecoding")
+
     for sub in range(nsubs):
 
         ns = np.zeros([n], dtype=int)
@@ -310,7 +324,7 @@ def tbyt_decoding_holdout(data, labels, n=2, navg=5, time_win=5, time_step=5, it
 
         acc[sub] = np.average(subacc, axis=0)
 
-    if smooth == True:
+    if smooth is True:
 
         smooth_acc = np.zeros([nsubs, newnts])
 
@@ -373,6 +387,8 @@ def ct_decoding_kfold(data, labels, n=2, navg=5, time_win=5, time_step=5, nfolds
 
     if np.shape(data)[0] != np.shape(labels)[0]:
 
+        print("\nThe number of epochs doesn't match the number of labels.\n")
+
         return "Invalid input!"
 
     nsubs, ntrials, nchls, nts = np.shape(data)
@@ -388,10 +404,14 @@ def ct_decoding_kfold(data, labels, n=2, navg=5, time_win=5, time_step=5, nfolds
 
     if len(set(ncategories.tolist())) != 1:
 
+        print("\nInvalid labels!\n")
+
         return "Invalid input!"
 
     if n != ncategories[0]:
 
+        print("\nThe number of categories for decoding doesn't match ncategories (" + str(ncategories) + ")!\n")
+
         return "Invalid input!"
 
     categories = list(sublabels_set)
@@ -408,6 +428,8 @@ def ct_decoding_kfold(data, labels, n=2, navg=5, time_win=5, time_step=5, nfolds
 
     total = nsubs*nrepeats*newnts*nfolds
 
+    print("\nDecoding")
+
     for sub in range(nsubs):
 
         ns = np.zeros([n], dtype=int)
@@ -468,9 +490,10 @@ def ct_decoding_kfold(data, labels, n=2, navg=5, time_win=5, time_step=5, nfolds
                     for tt in range(newnts - 1):
                         if tt < t:
                             xtt = x[:, :, tt]
+                            subacc[i, t, tt, fold_index] = svm.score(xtt[test_index], y[test_index])
                         if tt >= t:
                             xtt = x[:, :, tt + 1]
-                        subacc[i, t, tt, fold_index] = svm.score(xtt[test_index], y[test_index])
+                            subacc[i, t, tt+1, fold_index] = svm.score(xtt[test_index], y[test_index])
 
                     if sub == (nsubs-1) and i == (nrepeats-1) and t == (newnts - 1) and fold_index == (nfolds - 1):
                         print("\nDecoding finished!\n")
@@ -517,7 +540,7 @@ def ct_decoding_kfold(data, labels, n=2, navg=5, time_win=5, time_step=5, nfolds
 def ct_decoding_holdout(data, labels, n=2, navg=5, time_win=5, time_step=5, iter=10, test_size=0.3, smooth=True):
 
     """
-    Conduct time-by-time decoding for EEG-like data (hold-out)
+    Conduct cross-temporal decoding for EEG-like data (hold-out)
 
     Parameters
     ----------
@@ -555,6 +578,8 @@ def ct_decoding_holdout(data, labels, n=2, navg=5, time_win=5, time_step=5, iter
 
     if np.shape(data)[0] != np.shape(labels)[0]:
 
+        print("\nThe number of epochs doesn't match the number of labels.\n")
+
         return "Invalid input!"
 
     nsubs, ntrials, nchls, nts = np.shape(data)
@@ -570,10 +595,14 @@ def ct_decoding_holdout(data, labels, n=2, navg=5, time_win=5, time_step=5, iter
 
     if len(set(ncategories.tolist())) != 1:
 
+        print("\nInvalid labels!\n")
+
         return "Invalid input!"
 
     if n != ncategories[0]:
 
+        print("\nThe number of categories for decoding doesn't match ncategories (" + str(ncategories) + ")!\n")
+
         return "Invalid input!"
 
     categories = list(sublabels_set)
@@ -590,6 +619,8 @@ def ct_decoding_holdout(data, labels, n=2, navg=5, time_win=5, time_step=5, iter
 
     total = nsubs * iter * newnts
 
+    print("\nDecoding")
+
     for sub in range(nsubs):
 
         ns = np.zeros([n], dtype=int)
@@ -659,7 +690,7 @@ def ct_decoding_holdout(data, labels, n=2, navg=5, time_win=5, time_step=5, iter
 
         acc[sub] = np.average(subacc, axis=0)
 
-    if smooth == True:
+    if smooth is True:
 
         smooth_acc = np.zeros([nsubs, newnts, newnts])
 
@@ -692,11 +723,13 @@ def ct_decoding_holdout(data, labels, n=2, navg=5, time_win=5, time_step=5, iter
         return acc
 
 
+' a function for unidirectional transfer decoding for EEG-like data (cross validation) '
+
 def unidirectional_transfer_decoding_kfold(data1, labels1, data2, labels2, n=2, navg=5, time_win=5, time_step=5,
                                            nfolds=5, nrepeats=2, smooth=True):
 
     """
-    Conduct unidirectional transfer decoding for EEG-like data
+    Conduct unidirectional transfer decoding for EEG-like data (cross validation)
 
     Parameters
     ----------
@@ -723,6 +756,11 @@ def unidirectional_transfer_decoding_kfold(data1, labels1, data2, labels2, n=2,
         The time step size for each time of decoding.
     iter : int. Default is 10.
         The times for iteration.
+    nfolds : int. Default is 5.
+        Number of folds.
+        nfolds should be at least 2.
+    nrepeats : int. Default is 2.
+        The times for iteration.
     smooth : boolean True or False. Default is True.
         Smooth the decoding result or not.
 
@@ -734,18 +772,26 @@ def unidirectional_transfer_decoding_kfold(data1, labels1, data2, labels2, n=2,
 
     if np.shape(data1)[0] != np.shape(labels1)[0]:
 
+        print("\nThe number of epochs doesn't match the number of labels.\n")
+
         return "Invalid input!"
 
     if np.shape(data2)[0] != np.shape(labels2)[0]:
 
+        print("\nThe number of epochs doesn't match the number of labels.\n")
+
         return "Invalid input!"
 
     if np.shape(data1)[0] != np.shape(data2)[0]:
 
+        print("\nThe number of subjects of data1 doesn't match the number of subjects of data2.\n")
+
         return "Invalid input!"
 
     if np.shape(data1)[2] != np.shape(data2)[2]:
 
+        print("\nThe number of channels of data1 doesn't match the number of channels of data2.\n")
+
         return "Invalid input!"
 
     nsubs, ntrials1, nchls, nts1 = np.shape(data1)
@@ -762,10 +808,14 @@ def unidirectional_transfer_decoding_kfold(data1, labels1, data2, labels2, n=2,
 
     if len(set(ncategories1.tolist())) != 1:
 
+        print("\nInvalid labels!\n")
+
         return "Invalid input!"
 
     if n != ncategories1[0]:
 
+        print("\nThe number of categories for decoding doesn't match ncategories1 (" + str(ncategories1) + ")!\n")
+
         return "Invalid input!"
 
     ncategories2 = np.zeros([nsubs], dtype=int)
@@ -777,14 +827,21 @@ def unidirectional_transfer_decoding_kfold(data1, labels1, data2, labels2, n=2,
         ncategories2[sub] = len(sublabels2_set)
 
     if len(set(ncategories2.tolist())) != 1:
+
+        print("\nInvalid labels!\n")
+
         return "Invalid input!"
 
     if n != ncategories2[0]:
 
+        print("\nThe number of categories for decoding doesn't match ncategories2 (" + str(ncategories2) + ")!\n")
+
         return "Invalid input!"
 
     if ncategories1[0] != ncategories2[0]:
 
+        print("\nThe number of categories of data1 doesn't match the number of categories of data2.\n")
+
         return "Invalid input!"
 
     categories = list(sublabels1_set)
@@ -807,6 +864,8 @@ def unidirectional_transfer_decoding_kfold(data1, labels1, data2, labels2, n=2,
 
     total = nsubs * nrepeats * newnts1
 
+    print("\nDecoding")
+
     for sub in range(nsubs):
 
         ns1 = np.zeros([n], dtype=int)
@@ -899,9 +958,9 @@ def unidirectional_transfer_decoding_kfold(data1, labels1, data2, labels2, n=2,
                 if sub == (nsubs-1) and i == (nrepeats-1) and t == (newnts1 - 1):
                     print("\nDecoding finished!\n")
 
-        acc[sub] = np.average(subacc, axis=0)
+        acc[sub] = np.average(subacc, axis=(0, 3))
 
-    if smooth == True:
+    if smooth is True:
 
         smooth_acc = np.zeros([nsubs, newnts1, newnts2])
 
@@ -934,11 +993,13 @@ def unidirectional_transfer_decoding_kfold(data1, labels1, data2, labels2, n=2,
         return acc
 
 
-def unidirectional_transfer_decoding_handout(data1, labels1, data2, labels2, n=2, navg=5, time_win=5, time_step=5, iter=10,
-                                     smooth=True):
+' a function for unidirectional transfer decoding for EEG-like data (hold out) '
+
+def unidirectional_transfer_decoding_holdout(data1, labels1, data2, labels2, n=2, navg=5, time_win=5, time_step=5,
+                                             iter=10, smooth=True):
 
     """
-    Conduct unidirectional transfer decoding for EEG-like data
+    Conduct unidirectional transfer decoding for EEG-like data (hold out)
 
     Parameters
     ----------
@@ -976,18 +1037,26 @@ def unidirectional_transfer_decoding_handout(data1, labels1, data2, labels2, n=2
 
     if np.shape(data1)[0] != np.shape(labels1)[0]:
 
+        print("\nThe number of epochs doesn't match the number of labels.\n")
+
         return "Invalid input!"
 
     if np.shape(data2)[0] != np.shape(labels2)[0]:
 
+        print("\nThe number of epochs doesn't match the number of labels.\n")
+
         return "Invalid input!"
 
     if np.shape(data1)[0] != np.shape(data2)[0]:
 
+        print("\nThe number of subjects of data1 doesn't match the number of subjects of data2.\n")
+
         return "Invalid input!"
 
     if np.shape(data1)[2] != np.shape(data2)[2]:
 
+        print("\nThe number of channels of data1 doesn't match the number of channels of data2.\n")
+
         return "Invalid input!"
 
     nsubs, ntrials1, nchls, nts1 = np.shape(data1)
@@ -1004,10 +1073,14 @@ def unidirectional_transfer_decoding_handout(data1, labels1, data2, labels2, n=2
 
     if len(set(ncategories1.tolist())) != 1:
 
+        print("\nInvalid labels!\n")
+
         return "Invalid input!"
 
     if n != ncategories1[0]:
 
+        print("\nThe number of categories for decoding doesn't match ncategories1 (" + str(ncategories1) + ")!\n")
+
         return "Invalid input!"
 
     ncategories2 = np.zeros([nsubs], dtype=int)
@@ -1019,14 +1092,21 @@ def unidirectional_transfer_decoding_handout(data1, labels1, data2, labels2, n=2
         ncategories2[sub] = len(sublabels2_set)
 
     if len(set(ncategories2.tolist())) != 1:
+
+        print("\nInvalid labels!\n")
+
         return "Invalid input!"
 
     if n != ncategories2[0]:
 
+        print("\nThe number of categories for decoding doesn't match ncategories2 (" + str(ncategories2) + ")!\n")
+
         return "Invalid input!"
 
     if ncategories1[0] != ncategories2[0]:
 
+        print("\nThe number of categories of data1 doesn't match the number of categories of data2.\n")
+
         return "Invalid input!"
 
     categories = list(sublabels1_set)
@@ -1049,6 +1129,8 @@ def unidirectional_transfer_decoding_handout(data1, labels1, data2, labels2, n=2
 
     total = nsubs * iter * newnts1
 
+    print("\nDecoding")
+
     for sub in range(nsubs):
 
         ns1 = np.zeros([n], dtype=int)
@@ -1136,7 +1218,7 @@ def unidirectional_transfer_decoding_handout(data1, labels1, data2, labels2, n=2
 
         acc[sub] = np.average(subacc, axis=0)
 
-    if smooth == True:
+    if smooth is True:
 
         smooth_acc = np.zeros([nsubs, newnts1, newnts2])
 
