@@ -113,7 +113,7 @@ def corr_save_nii(corrs, affine, filename=None, corr_mask=get_HOcort(), size=[60
                 y = j*sy
                 z = k*sz
 
-                if (math.isnan(corrs[i, j, k, 0]) is False):
+                if (math.isnan(corrs[i, j, k, 0]) == False):
 
                     for k1 in range(kx):
                         for k2 in range(ky):
@@ -164,7 +164,7 @@ def corr_save_nii(corrs, affine, filename=None, corr_mask=get_HOcort(), size=[60
                 y = j*sy
                 z = k*sz
 
-                if (math.isnan(corrs[i, j, k, 0]) is False):
+                if (math.isnan(corrs[i, j, k, 0]) == False):
 
                     for k1 in range(kx):
                         for k2 in range(ky):
@@ -345,7 +345,7 @@ def stats_save_nii(corrs, affine, filename=None, corr_mask=get_HOcort(), size=[6
                 y = j*sy
                 z = k*sz
 
-                if (math.isnan(corrs[i, j, k, 0]) is False):
+                if (math.isnan(corrs[i, j, k, 0]) == False):
 
                     for k1 in range(kx):
                         for k2 in range(ky):
@@ -422,7 +422,7 @@ def stats_save_nii(corrs, affine, filename=None, corr_mask=get_HOcort(), size=[6
                 y = j*sy
                 z = k*sz
 
-                if (math.isnan(corrs[i, j, k, 0]) is False):
+                if (math.isnan(corrs[i, j, k, 0]) == False):
 
                     for k1 in range(kx):
                         for k2 in range(ky):
@@ -473,7 +473,7 @@ def stats_save_nii(corrs, affine, filename=None, corr_mask=get_HOcort(), size=[6
         for i in range(nx):
             for j in range(ny):
                 for k in range(nz):
-                    if (math.isnan(mask[i, j, k]) is True) or mask[i, j, k] == 0:
+                    if (math.isnan(mask[i, j, k]) == True) or mask[i, j, k] == 0:
                         newimg_nii[i, j, k] = np.nan
                     if newimg_nii[i, j, k] < t_threshold and newimg_nii[i, j, k] > 0:
                         newimg_nii[i, j, k] = np.nan
