@@ -11,8 +11,9 @@ from scipy import signal
 from scipy.stats import ttest_1samp
 from nilearn import plotting, datasets, surface
 import nibabel as nib
-from neurora.stuff import get_affine, permutation_test, correct_by_threshold, get_bg_ch2, get_bg_ch2bet, \
+from neurora.stuff import get_affine, correct_by_threshold, get_bg_ch2, get_bg_ch2bet, \
     clusterbased_permutation_1d_1samp_1sided, clusterbased_permutation_2d_1samp_1sided
+from decimal import Decimal
 
 
 ' a function for plotting the RDM '
@@ -452,8 +453,9 @@ def plot_tbytsim_withstats(similarities, start_time=0, end_time=1, smooth=True,
 
 ' a function for plotting the time-by-time decoding accuracies '
 
-def plot_tbyt_decoding_acc(acc, start_time=0, end_time=1, time_interval=0.01, chance=0.5, p=0.05, cbpt=True, color='r',
-                           lim=[0.4, 0.8], figsize=[6.4, 3.6], x0=0, fontsize=16, avgshow=False):
+def plot_tbyt_decoding_acc(acc, start_time=0, end_time=1, time_interval=0.01, chance=0.5, p=0.05, cbpt=True,
+                           stats_time=[0, 1], color='r', xlim=[0, 1], ylim=[0.4, 0.8], figsize=[6.4, 3.6], x0=0,
+                           fontsize=16, avgshow=False):
 
     """
     Plot the time-by-time decoding accuracies
@@ -476,10 +478,14 @@ def plot_tbyt_decoding_acc(acc, start_time=0, end_time=1, time_interval=0.01, ch
         The threshold of p-values.
     cbpt : bool True or False. Default is True.
         Conduct cluster-based permutation test or not.
+    stats_time : array or list [stats_time1, stats_time2]. Default os [0, 1].
+        Time period for statistical analysis.
     color : matplotlib color or None. Default is 'r'.
         The color for the curve.
-    lim : array or list [min, max]. Default is [0.4, 0.8].
-        The corrs view lims.
+    xlim : array or list [xmin, xmax]. Default is [0, 1].
+        The x-axis (time) view lims.
+    ylim : array or list [ymin, ymax]. Default is [0.4, 0.8].
+        The y-axis (decoding accuracy) view lims.
     figsize : array or list, [size_X, size_Y]. Default is [6.4, 3.6].
         The size of the figure.
     x0 : float. Default is 0.
@@ -495,14 +501,25 @@ def plot_tbyt_decoding_acc(acc, start_time=0, end_time=1, time_interval=0.01, ch
         return "Invalid input!"
 
     nsubs, nts = np.shape(acc)
-    tstep = (end_time-start_time)/nts
+    tstep = float(Decimal((end_time - start_time) / nts).quantize(Decimal(str(time_interval))))
 
     if tstep != time_interval:
 
         return "Invalid input!"
 
-    minlim = lim[0]
-    maxlim = lim[1]
+    delta1 = (stats_time[0] - start_time) / tstep - int((stats_time[0] - start_time) / tstep)
+    delta2 = (stats_time[1] - start_time) / tstep - int((stats_time[1] - start_time) / tstep)
+    if delta1 == 0:
+        stats_time1 = int((stats_time[0] - start_time) / tstep)
+    else:
+        stats_time1 = int((stats_time[0] - start_time) / tstep) + 1
+    if delta2 == 0:
+        stats_time2 = int((stats_time[1] - start_time) / tstep)
+    else:
+        stats_time2 = int((stats_time[1] - start_time) / tstep) + 1
+
+    yminlim = ylim[0]
+    ymaxlim = ylim[1]
 
     avg = np.average(acc, axis=0)
     err = np.zeros([nts])
@@ -511,20 +528,24 @@ def plot_tbyt_decoding_acc(acc, start_time=0, end_time=1, time_interval=0.01, ch
 
     if cbpt == True:
 
-        ps = clusterbased_permutation_1d_1samp_1sided(acc, level=chance, p_threshold=p, iter=1000)
+        ps_stats = clusterbased_permutation_1d_1samp_1sided(acc[:, stats_time1:stats_time2], level=chance,
+                                                            p_threshold=p, iter=1000)
+        ps = np.zeros([nts])
+        ps[stats_time1:stats_time2] = ps_stats
 
     else:
         ps = np.zeros([nts])
         for t in range(nts):
-            ps[t] = ttest_1samp(acc[:, t], chance, alternative="greater")[1]
-            if ps[t] < p:
-                ps[t] = 1
-            else:
-                ps[t] = 0
+            if t >= stats_time1 and t< stats_time2:
+                ps[t] = ttest_1samp(acc[:, t], chance, alternative="greater")[1]
+                if ps[t] < p:
+                    ps[t] = 1
+                else:
+                    ps[t] = 0
 
     for t in range(nts):
         if ps[t] == 1:
-            plt.plot(t*tstep+start_time, (maxlim-minlim)*0.9+minlim, 's', color=color, alpha=0.8)
+            plt.plot(t*tstep+start_time, (ymaxlim-yminlim)*0.9+yminlim, 's', color=color, alpha=0.8)
             xi = [t*tstep+start_time, t*tstep+tstep+start_time]
             ymin = [chance]
             ymax = [avg[t] - err[t]]
@@ -539,12 +560,12 @@ def plot_tbyt_decoding_acc(acc, start_time=0, end_time=1, time_interval=0.01, ch
     ax.spines["left"].set_position(("data", x0))
     ax.spines["bottom"].set_linewidth(3)
     ax.spines["bottom"].set_position(("data", chance))
-    x = np.arange(start_time, end_time, tstep)
+    x = np.arange(start_time+0.5*tstep, end_time+0.5*tstep, tstep)
     if avgshow is True:
         plt.plot(x, avg, color=color, alpha=0.9)
     plt.fill_between(x, avg+err, avg-err, facecolor=color, alpha=0.8)
-    plt.ylim(minlim, maxlim)
-    plt.xlim(start_time, end_time)
+    plt.ylim(yminlim, ymaxlim)
+    plt.xlim(xlim[0], xlim[1])
     plt.tick_params(labelsize=12)
     plt.xlabel("Time (s)", fontsize=fontsize)
     plt.ylabel("Decoding Accuracy", fontsize=fontsize)
@@ -553,8 +574,9 @@ def plot_tbyt_decoding_acc(acc, start_time=0, end_time=1, time_interval=0.01, ch
 
 ' a function for plotting cross-temporal decoding accuracies '
 
-def plot_ct_decoding_acc(acc, start_timex=0, end_timex=1, start_timey=0, end_timey=1, chance=0.5, p=0.05, cbpt=True,
-                         lim=[0.4, 0.8], figsize=[6.4, 4.8], cmap="viridis", fontsize=16):
+def plot_ct_decoding_acc(acc, start_timex=0, end_timex=1, start_timey=0, end_timey=1, time_intervalx=0.01,
+                         time_intervaly=0.01, chance=0.5, p=0.05, cbpt=True, stats_timex=[0, 1], stats_timey=[0, 1],
+                         xlim=[0, 1], ylim=[0, 1], clim=[0.4, 0.8], figsize=[6.4, 4.8], cmap="viridis", fontsize=16):
 
     """
     Plot the cross-temporal decoding accuracies
@@ -569,53 +591,97 @@ def plot_ct_decoding_acc(acc, start_timex=0, end_timex=1, start_timey=0, end_tim
         The training start time.
     end_timex : int or float. Default is 1.
         The training end time.
-    start_timex : int or float. Default is 0.
+    start_timey : int or float. Default is 0.
         The test start time.
-    end_timex : int or float. Default is 1.
+    end_timey : int or float. Default is 1.
         The test end time.
+    time_intervalx : float. Default is 0.01.
+        The training time interval between two time samples.
+    time_intervaly : float. Default is 0.01.
+        The test time interval between two time samples.
     chance : float. Default is 0.5.
         The chance level.
     p : float. Default is 0.05.
         The threshold of p-values.
     cbpt : bool True or False. Default is True.
         Conduct cluster-based permutation test or not.
-    lim : array or list [min, max]. Default is [0.4, 0.8].
-        The corrs view lims.
+    stats_timex : array or list [stats_timex1, stats_timex2]. Default os [0, 1].
+        Trainning time period for statistical analysis.
+    stats_timey : array or list [stats_timey1, stats_timey2]. Default os [0, 1].
+        Test time period for statistical analysis.
+    xlim : array or list [xmin, xmax]. Default is [0, 1].
+        The x-axis (training time) view lims.
+    ylim : array or list [ymin, ymax]. Default is [0, 1].
+        The y-axis (test time) view lims.
+    clim : array or list [cmin, cmax]. Default is [0.4, 0.8].
+        The color-bar (decoding accuracy) view lims.
     figsize : array or list, [size_X, size_Y]. Default is [6.4, 3.6].
         The size of the figure.
-    cmap :
+    cmap : matplotlib colormap or None. Default is None.
+        The colormap for the figure.
     fontsize : int or float. Default is 16.
         The fontsize of the labels.
     """
 
     nsubs, nx, ny = np.shape(acc)
-    acc = np.transpose(acc, (0, 2, 1))
-    minlim = lim[0]
-    maxlim = lim[1]
+    cminlim = clim[0]
+    cmaxlim = clim[1]
 
-    tstepx = (end_timex-start_timex)/nx
-    tstepy = (end_timey-start_timey)/ny
+    tstepx = float(Decimal((end_timex - start_timex) / nx).quantize(Decimal(str(time_intervalx))))
+    tstepy = float(Decimal((end_timey - start_timey) / ny).quantize(Decimal(str(time_intervaly))))
+    print(tstepx, tstepy)
+    print(time_intervalx, time_intervaly)
+
+    if tstepx != time_intervalx or tstepy != time_intervaly:
+        return "Invalid input!"
+
+    deltax1 = (stats_timex[0] - start_timex) / tstepx - int((stats_timex[0] - start_timex) / tstepx)
+    deltax2 = (stats_timex[1] - start_timex) / tstepx - int((stats_timex[1] - start_timex) / tstepx)
+    if deltax1 == 0:
+        stats_timex1 = int((stats_timex[0] - start_timex) / tstepx)
+    else:
+        stats_timex1 = int((stats_timex[0] - start_timex) / tstepx) + 1
+    if deltax2 == 0:
+        stats_timex2 = int((stats_timex[1] - start_timex) / tstepx)
+    else:
+        stats_timex2 = int((stats_timex[1] - start_timex) / tstepx) + 1
+
+    deltay1 = (stats_timey[0] - start_timey) / tstepy - int((stats_timey[0] - start_timey) / tstepy)
+    deltay2 = (stats_timey[1] - start_timey) / tstepy - int((stats_timey[1] - start_timey) / tstepy)
+    if deltay1 == 0:
+        stats_timey1 = int((stats_timey[0] - start_timey) / tstepy)
+    else:
+        stats_timey1 = int((stats_timey[0] - start_timey) / tstepy) + 1
+    if deltay2 == 0:
+        stats_timey2 = int((stats_timey[1] - start_timey) / tstepy)
+    else:
+        stats_timey2 = int((stats_timey[1] - start_timey) / tstepy) + 1
 
     if cbpt is True:
 
-        ps = clusterbased_permutation_2d_1samp_1sided(acc, level=chance, p_threshold=p, iter=1000)
+        ps_stats = clusterbased_permutation_2d_1samp_1sided(
+            acc[:, stats_timex1:stats_timex2, stats_timey1:stats_timey2], level=chance, p_threshold=p, iter=1000)
+        ps = np.zeros([nx, ny])
+        ps[stats_timex1:stats_timex2, stats_timey1:stats_timey2] = ps_stats
 
     else:
         ps = np.zeros([nx, ny])
         for t1 in range(nx):
             for t2 in range(ny):
-                ps[t1, t2] = ttest_1samp(acc[:, t1, t2], chance, alternative="greater")[1]
-                if ps[t1, t2] < p:
-                    ps[t1, t2] = 1
-                else:
-                    ps[t1, t2] = 0
+                if t1 >= stats_timex1 and t1 < stats_timex2 and t2 >= stats_timey1 and t2 < stats_timey2:
+                    ps[t1, t2] = ttest_1samp(acc[:, t1, t2], chance, alternative="greater")[1]
+                    if ps[t1, t2] < p:
+                        ps[t1, t2] = 1
+                    else:
+                        ps[t1, t2] = 0
 
-    newps = np.zeros([nx+2, ny+2])
-    newps[1:nx+1, 1:nx+1] = ps
-    x = np.linspace(start_timex-0.5*tstepx, end_timex+0.5*tstepx, nx+2)
-    y = np.linspace(start_timey-0.5*tstepy, end_timey+0.5*tstepy, ny+2)
+    newps = np.zeros([nx + 2, ny + 2])
+    newps[1:nx + 1, 1:ny + 1] = ps
+    x = np.linspace(start_timex - 0.5 * tstepx, end_timex + 0.5 * tstepx, nx + 2)
+    y = np.linspace(start_timey - 0.5 * tstepy, end_timey + 0.5 * tstepy, ny + 2)
     X, Y = np.meshgrid(x, y)
-    plt.contour(X, Y, newps, [0, 1], colors="silver", alpha=0.9, linewidths=3, linestyles="dashed")
+    plt.contour(X, Y, np.transpose(newps, (1, 0)), [0, 1], colors="silver", alpha=0.9, linewidths=3,
+                linestyles="dashed")
 
     fig = plt.gcf()
     fig.set_size_inches(figsize[0], figsize[1])
@@ -625,13 +691,15 @@ def plot_ct_decoding_acc(acc, start_timex=0, end_timex=1, start_timey=0, end_tim
     ax.spines["left"].set_linewidth(2)
     ax.spines["bottom"].set_linewidth(2)
     avg = np.average(acc, axis=0)
-    plt.imshow(avg, extent=(start_timex, end_timex, start_timey, end_timey), cmap=cmap, origin="lower", clim=(minlim, maxlim))
+    avg = np.transpose(avg, (1, 0))
+    plt.imshow(avg, extent=(start_timex, end_timex, start_timey, end_timey), cmap=cmap, origin="lower",
+               clim=(cminlim, cmaxlim))
     cb = plt.colorbar()
     cb.ax.tick_params(labelsize=12)
     font = {'size': 15}
     cb.set_label("Decoding Accuracy", fontdict=font)
-    plt.xlim(start_timex, end_timex)
-    plt.ylim(start_timey, end_timey)
+    plt.xlim(xlim[0], xlim[1])
+    plt.ylim(ylim[0], ylim[1])
     plt.tick_params(labelsize=12)
     plt.xlabel("Training Time (s)", fontsize=fontsize)
     plt.ylabel("Test Time (s)", fontsize=fontsize)
@@ -931,7 +999,7 @@ def plot_corrs_hotmap_stats(corrs, stats, chllabels=None, time_unit=[0, 0.1], li
         pid_list.sort()
         for j in range(ts):
             index = j in pid_list
-            if index is False:
+            if index == False:
                 ps[i, j] = 0
 
     newps = np.zeros([nchls + 2, ts + 2], dtype=np.float)
@@ -1264,7 +1332,7 @@ def plot_stats_hotmap(stats, chllabels=None, time_unit=[0, 0.1], lim=[-7, 7], sm
             pid_list.sort()
             for j in range(ts):
                 index = j in pid_list
-                if index is False:
+                if index == False:
                     ps[i, j] = 0
 
         newps = np.zeros([nchls+2, ts+2], dtype=np.float)
