@@ -7,6 +7,7 @@ __author__ = 'Zitong Lu'
 import numpy as np
 from scipy.stats import pearsonr
 import math
+from neurora.stuff import show_progressbar
 
 np.seterr(divide='ignore', invalid='ignore')
 
@@ -48,8 +49,12 @@ def stps(data, label_item, label_rf, time_win=20, time_step=1):
 
     if len(np.shape(data)) != 4:
 
+        print("\nThe shape of input should be [n_subs, n_trials, n_chls, n_ts].\n")
+
         return "Invalid input!"
 
+    print("\nComputing NPS")
+
     # get the number of subjects, trials, channels/regions & time-points
     subs, trials, chls, ts = np.shape(data)
 
@@ -59,6 +64,8 @@ def stps(data, label_item, label_rf, time_win=20, time_step=1):
     # initialize the STPS
     stps = np.zeros([subs, 8, chls, ts], dtype=np.float)
 
+    total = subs * chls * ts
+
     for sub in range(subs):
 
         # initialize the STPS for each subject
@@ -67,6 +74,10 @@ def stps(data, label_item, label_rf, time_win=20, time_step=1):
         for i in range(chls):
             for j in range(ts):
 
+                # show the progressbar
+                percent = (sub * chls * ts + i * ts + j) / total * 100
+                show_progressbar("Calculating", percent)
+
                 trials_data = data[sub, :, i, ts*time_step:ts*time_step+time_win]
 
                 corr_mat = np.zeros([trials, trials], dtype=np.float)
@@ -159,6 +170,8 @@ def stps(data, label_item, label_rf, time_win=20, time_step=1):
 
         stps[sub] = sub_stps
 
+    print("\nComputing finished!")
+
     return stps
 
 
@@ -204,8 +217,12 @@ def stps_fmri(fmri_data, label_item, label_rf, ksize=[3, 3, 3], strides=[1, 1, 1
 
     if len(np.shape(fmri_data)) != 5:
 
+        print("\nThe shape of input should be [n_subs, n_trials, nx, ny, nz].\n")
+
         return "Invalid input!"
 
+    print("\nComputing NPS")
+
     # get the number of subjects, trials and the size of the fMRI-img
     subs, trials, nx, ny, nz = np.shape(fmri_data)
 
@@ -215,7 +232,10 @@ def stps_fmri(fmri_data, label_item, label_rf, ksize=[3, 3, 3], strides=[1, 1, 1
     kz = ksize[2]
 
     if kx + ky + kz < 9:
-        return print("The size of the calculation units is too small.")
+
+        print("\nThe size of the calculation units is too small.\n")
+
+        return "Invalid size of ksize!"
 
     # strides for calculating along the x, y, z axis
     sx = strides[0]
@@ -230,6 +250,8 @@ def stps_fmri(fmri_data, label_item, label_rf, ksize=[3, 3, 3], strides=[1, 1, 1
     # initialize the STPS
     stps = np.zeros([subs, 8, n_x, n_y, n_z], dtype=np.float)
 
+    total = subs * n_x * n_y * n_z
+
     for sub in range(subs):
 
         # initialize the STPS for each subject
@@ -239,6 +261,10 @@ def stps_fmri(fmri_data, label_item, label_rf, ksize=[3, 3, 3], strides=[1, 1, 1
             for y in range(n_y):
                 for z in range(n_z):
 
+                    # show the progressbar
+                    percent = (sub * n_x * n_y * n_z + x * n_y * n_z + y * n_z + z) / total * 100
+                    show_progressbar("Calculating", percent)
+
                     trials_data = fmri_data[sub, :, x*sx:x*sx+kx, y*sy:y*sy+ky, z*sz:z*sz+kz]
                     trials_data = np.reshape(trials_data, [trials, kx*ky*kz])
 
@@ -332,6 +358,8 @@ def stps_fmri(fmri_data, label_item, label_rf, ksize=[3, 3, 3], strides=[1, 1, 1
 
         stps[sub] = sub_stps
 
+    print("\nComputing finished!")
+
     return stps
 
 
@@ -371,10 +399,20 @@ def stps_fmri_roi(fmri_data, mask_data, label_item, label_rf):
     The size of the calculation units should at least be [3, 3, 3].
     """
 
-    if len(np.shape(fmri_data)) != 5 or len(np.shape(mask_data)) != 3:
+    if len(np.shape(fmri_data)) != 5:
+
+        print("\nThe shape of fmri data should be [2, n_subs, nx, ny, nz].\n")
 
         return "Invalid input!"
 
+    if len(np.shape(mask_data)) != 3:
+
+        print("\nThe shape of fmri data should be [nx, ny, nz].\n")
+
+        return "Invalid input!"
+
+    print("\nComputing NPS")
+
     # get the number of subjects, trials and the size of the fMRI-img
     subs, trials, nx, ny, nz = np.shape(fmri_data)
 
@@ -386,7 +424,7 @@ def stps_fmri_roi(fmri_data, mask_data, label_item, label_rf):
             for k in range(nz):
 
                 # not 0 or NaN
-                if (mask_data[i, j, k] != 0) and (math.isnan(mask_data[i, j, k]) is False):
+                if (mask_data[i, j, k] != 0) and (math.isnan(mask_data[i, j, k]) == False):
                     nmask = nmask + 1
 
     # initialize the data for calculating the ISC
@@ -403,7 +441,7 @@ def stps_fmri_roi(fmri_data, mask_data, label_item, label_rf):
                     for k in range(nz):
 
                         # not 0 or NaN
-                        if (mask_data[i, j, k] != 0) and (math.isnan(mask_data[i, j, k]) is False):
+                        if (mask_data[i, j, k] != 0) and (math.isnan(mask_data[i, j, k]) == False):
                             data[sub, tr, n] = fmri_data[sub, tr, i, j, k]
                             n = n + 1
 
@@ -506,4 +544,6 @@ def stps_fmri_roi(fmri_data, mask_data, label_item, label_rf):
 
         stps[sub] = sub_stps
 
+    print("\nComputing finished!")
+
     return stps
\ No newline at end of file
