@@ -942,7 +942,7 @@ def get_cluster_index_2d_2sided(m):
             index = True
             if b1[ii-1, jj] != 1 and b1[ii+1, jj] != 1 and b1[ii, jj-1] != 1 and b1[ii, jj+1] != 1:
                 index = False
-            if b1[ii, jj] == 1 and index is True:
+            if b1[ii, jj] == 1 and index == True:
                 min_index = index_n1 + 1
                 if b1[ii - 1, jj] == 1:
                     min_index = np.min([min_index, index_m1[i - 1, j]])
@@ -982,7 +982,7 @@ def get_cluster_index_2d_2sided(m):
             index = True
             if b2[ii - 1, jj] != -1 and b2[ii + 1, jj] != -1 and b2[ii, jj - 1] != -1 and b2[ii, jj + 1] != -1:
                 index = False
-            if b2[ii, jj] == -1 and index is True:
+            if b2[ii, jj] == -1 and index == True:
                 min_index = index_n2 + 1
                 if b2[ii - 1, jj] == -1:
                     min_index = np.min([min_index, index_m2[i - 1, j]])
@@ -1068,6 +1068,8 @@ def clusterbased_permutation_1d_1samp_1sided(results, level=0, p_threshold=0.05,
 
         permu_ts = np.zeros([iter])
         chance = np.full([nsubs], level)
+        print("\nPermutation test")
+
         for i in range(iter):
             permu_cluster_ts = np.zeros([cluster_n])
             for j in range(cluster_n):
@@ -1079,6 +1081,9 @@ def clusterbased_permutation_1d_1samp_1sided(results, level=0, p_threshold=0.05,
                         v2 = vshuffle[nsubs:]
                         permu_cluster_ts[j] = permu_cluster_ts[j] + ttest_rel(v1, v2, alternative="greater")[0]
             permu_ts[i] = np.max(permu_cluster_ts)
+            show_progressbar("Calculating", (i+1)*100/iter)
+            if i == (iter - 1):
+                print("\nCluster-based permutation test finished!\n")
 
         for i in range(cluster_n):
             index = 0
@@ -1144,6 +1149,9 @@ def clusterbased_permutation_1d_1samp_2sided(results, level=0, p_threshold=0.05,
 
         permu_ts = np.zeros([iter])
         chance = np.full([nsubs], level)
+        print("\nPermutation test\n")
+        print("Side 1 begin:")
+
         for i in range(iter):
             permu_cluster_ts = np.zeros([cluster_n1])
             for j in range(cluster_n1):
@@ -1155,6 +1163,9 @@ def clusterbased_permutation_1d_1samp_2sided(results, level=0, p_threshold=0.05,
                         v2 = vshuffle[nsubs:]
                         permu_cluster_ts[j] = permu_cluster_ts[j] + ttest_rel(v1, v2, alternative="greater")[0]
             permu_ts[i] = np.max(permu_cluster_ts)
+            show_progressbar("Calculating", (i+1)*100/iter)
+            if i == (iter - 1):
+                print("\nSide 1 finished!\n")
 
         for i in range(cluster_n1):
             index = 0
@@ -1175,6 +1186,8 @@ def clusterbased_permutation_1d_1samp_2sided(results, level=0, p_threshold=0.05,
 
         permu_ts = np.zeros([iter])
         chance = np.full([nsubs], level)
+        print("Side 2 begin:\n")
+
         for i in range(iter):
             permu_cluster_ts = np.zeros([cluster_n2])
             for j in range(cluster_n2):
@@ -1186,6 +1199,10 @@ def clusterbased_permutation_1d_1samp_2sided(results, level=0, p_threshold=0.05,
                         v2 = vshuffle[nsubs:]
                         permu_cluster_ts[j] = permu_cluster_ts[j] + ttest_rel(v1, v2, alternative="less")[0]
             permu_ts[i] = np.max(permu_cluster_ts)
+            show_progressbar("Calculating", (i+1)*100/iter)
+            if i == (iter - 1):
+                print("\nSide 2 finished!\n")
+                print("Cluster-based permutation test finished!\n")
 
         for i in range(cluster_n2):
             index = 0
@@ -1252,6 +1269,8 @@ def clusterbased_permutation_2d_1samp_1sided(results, level=0, p_threshold=0.05,
 
         permu_ts = np.zeros([iter])
         chance = np.full([nsubs], level)
+        print("\nPermutation test")
+
         for i in range(iter):
             permu_cluster_ts = np.zeros([cluster_n])
             for j in range(cluster_n):
@@ -1264,6 +1283,9 @@ def clusterbased_permutation_2d_1samp_1sided(results, level=0, p_threshold=0.05,
                             v2 = vshuffle[nsubs:]
                             permu_cluster_ts[j] = permu_cluster_ts[j] + ttest_rel(v1, v2, alternative="greater")[0]
             permu_ts[i] = np.max(permu_cluster_ts)
+            show_progressbar("Calculating", (i+1)*100/iter)
+            if i == (iter - 1):
+                print("\nCluster-based permutation test finished!\n")
 
         for i in range(cluster_n):
             index = 0
@@ -1332,6 +1354,8 @@ def clusterbased_permutation_2d_1samp_2sided(results, level=0, p_threshold=0.05,
 
         permu_ts = np.zeros([iter])
         chance = np.full([nsubs], level)
+        print("\nPermutation test\n")
+        print("Side 1 begin:")
         for i in range(iter):
             permu_cluster_ts = np.zeros([cluster_n1])
             for j in range(cluster_n1):
@@ -1344,6 +1368,9 @@ def clusterbased_permutation_2d_1samp_2sided(results, level=0, p_threshold=0.05,
                             v2 = vshuffle[nsubs:]
                             permu_cluster_ts[j] = permu_cluster_ts[j] + ttest_rel(v1, v2, alternative="greater")[0]
             permu_ts[i] = np.max(permu_cluster_ts)
+            show_progressbar("Calculating", (i+1)*100/iter)
+            if i == (iter - 1):
+                print("\nSide 1 finished!\n")
 
         for i in range(cluster_n1):
             index = 0
@@ -1366,6 +1393,7 @@ def clusterbased_permutation_2d_1samp_2sided(results, level=0, p_threshold=0.05,
 
         permu_ts = np.zeros([iter])
         chance = np.full([nsubs], level)
+        print("Side 2 begin:\n")
         for i in range(iter):
             permu_cluster_ts = np.zeros([cluster_n2])
             for j in range(cluster_n2):
@@ -1378,6 +1406,10 @@ def clusterbased_permutation_2d_1samp_2sided(results, level=0, p_threshold=0.05,
                             v2 = vshuffle[nsubs:]
                             permu_cluster_ts[j] = permu_cluster_ts[j] + ttest_rel(v1, v2, alternative="less")[0]
             permu_ts[i] = np.max(permu_cluster_ts)
+            show_progressbar("Calculating", (i+1)*100/iter)
+            if i == (iter - 1):
+                print("\nSide 2 finished!\n")
+                print("Cluster-based permutation test finished!\n")
 
         for i in range(cluster_n2):
             index = 0
@@ -1454,6 +1486,8 @@ def clusterbased_permutation_2d_1sided(results1, results2, p_threshold=0.05, ite
                         cluster_ts[i] = cluster_ts[i] + ts[t1, t2]
 
         permu_ts = np.zeros([iter])
+        print("\nPermutation test")
+
         for i in range(iter):
             permu_cluster_ts = np.zeros([cluster_n])
             for j in range(cluster_n):
@@ -1466,6 +1500,9 @@ def clusterbased_permutation_2d_1sided(results1, results2, p_threshold=0.05, ite
                             v2 = vshuffle[nsubs:]
                             permu_cluster_ts[j] = permu_cluster_ts[j] + ttest_rel(v1, v2, alternative="greater")[0]
             permu_ts[i] = np.max(permu_cluster_ts)
+            show_progressbar("Calculating", (i+1)*100/iter)
+            if i == (iter - 1):
+                print("\nCluster-based permutation test finished!\n")
 
         for i in range(cluster_n):
             index = 0
@@ -1543,6 +1580,9 @@ def clusterbased_permutation_2d_2sided(results1, results2, p_threshold=0.05, ite
                         cluster_ts[i] = cluster_ts[i] + ts[t1, t2]
 
         permu_ts = np.zeros([iter])
+        print("\nPermutation test\n")
+        print("Side 1 begin:")
+
         for i in range(iter):
             permu_cluster_ts = np.zeros([cluster_n1])
             for j in range(cluster_n1):
@@ -1555,6 +1595,9 @@ def clusterbased_permutation_2d_2sided(results1, results2, p_threshold=0.05, ite
                             v2 = vshuffle[nsubs:]
                             permu_cluster_ts[j] = permu_cluster_ts[j] + ttest_rel(v1, v2, alternative="greater")[0]
             permu_ts[i] = np.max(permu_cluster_ts)
+            show_progressbar("Calculating", (i+1)*100/iter)
+            if i == (iter - 1):
+                print("\nSide 1 finished!\n")
 
         for i in range(cluster_n1):
             index = 0
@@ -1576,6 +1619,8 @@ def clusterbased_permutation_2d_2sided(results1, results2, p_threshold=0.05, ite
                         cluster_ts[i] = cluster_ts[i] + ts[t1, t2]
 
         permu_ts = np.zeros([iter])
+        print("Side 2 begin:\n")
+
         for i in range(iter):
             permu_cluster_ts = np.zeros([cluster_n2])
             for j in range(cluster_n2):
@@ -1588,6 +1633,10 @@ def clusterbased_permutation_2d_2sided(results1, results2, p_threshold=0.05, ite
                             v2 = vshuffle[nsubs:]
                             permu_cluster_ts[j] = permu_cluster_ts[j] + ttest_rel(v1, v2, alternative="less")[0]
             permu_ts[i] = np.max(permu_cluster_ts)
+            show_progressbar("Calculating", (i+1)*100/iter)
+            if i == (iter - 1):
+                print("\nSide 2 finished!\n")
+                print("Cluster-based permutation test finished!\n")
 
         for i in range(cluster_n2):
             index = 0
